@@ -18,15 +18,40 @@ def format_js(html: str, config: Config) -> str:
 
         indent = len(match.group(1)) * " "
         inner_indent = indent + config.indent
+
         opts = BeautifierOptions(config.js_config)
 
-        beautified = (
-            "\n"
-            + inner_indent
-            + ("\n" + inner_indent).join(
-                jsbeautifier.beautify(match.group(3), opts).splitlines()
-            )
-        )
+        beautified_lines = jsbeautifier.beautify(match.group(3), opts).splitlines()
+        beautified = ""
+
+        # add indent back
+        ignore_indent = False
+        for line in beautified_lines:
+
+            if re.search(
+                re.compile(
+                    r"\/\*[ ]*?beautify[ ]+?(?:preserve|ignore):end[ ]*?\*\/",
+                    re.DOTALL | re.IGNORECASE | re.MULTILINE,
+                ),
+                line,
+            ):
+                line = line.lstrip()
+                ignore_indent = False
+
+            if ignore_indent is False:
+
+                beautified += "\n" + inner_indent + line
+            else:
+                beautified += "\n" + line
+
+            if re.search(
+                re.compile(
+                    r"\/\*[ ]*?beautify[ ]+?(?:preserve|ignore):start[ ]*?\*\/",
+                    re.DOTALL | re.IGNORECASE | re.MULTILINE,
+                ),
+                line,
+            ):
+                ignore_indent = True
 
         return match.group(1) + match.group(2) + beautified + "\n" + indent
 
