@@ -8,8 +8,10 @@ from pathlib import Path
 
 from .formatter.compress import compress_html
 from .formatter.condense import condense_html
+from .formatter.css import format_css
 from .formatter.expand import expand_html
 from .formatter.indent import indent_html
+from .formatter.js import format_js
 from .settings import Config
 
 
@@ -18,11 +20,18 @@ def reformat_file(config: Config, this_file: Path) -> dict:
     rawcode = this_file.read_text(encoding="utf8")
 
     compressed = compress_html(rawcode, config)
-    expanded = expand_html(compressed, config)
-    condensed = condense_html(expanded, config)
-    indented = indent_html(condensed, config)
 
-    beautified_code = indented
+    expanded = expand_html(compressed, config)
+
+    condensed = condense_html(expanded, config)
+
+    beautified_code = indent_html(condensed, config)
+
+    if config.format_css:
+        beautified_code = format_css(beautified_code, config)
+
+    if config.format_js:
+        beautified_code = format_js(beautified_code, config)
 
     if config.check is not True:
         # update the file
